<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-form-item label="模板编号" prop="templateNo">
        <el-input
          v-model="dataForm.templateNo"
          placeholder="模板编号"
        ></el-input>
      </el-form-item>
      <el-form-item label="模板名称" prop="templateName">
        <el-input
          v-model="dataForm.templateName"
          placeholder="模板名称"
        ></el-input>
      </el-form-item>
      <el-form-item label="模板类型" prop="templateType">
        <el-select
          v-model="dataForm.templateType"
          placeholder="模板类型"
          filterable
          style="width: 100%"
          clearable
          @change="templateTypeChange"
        >
          <el-option
            v-for="item in templateTypeList"
            :key="item.id"
            :label="item.templateTypeName"
            :value="item.templateTypeName"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="dataForm.remark" placeholder="备注"></el-input>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj, getTemplateTypes } from '@/api/basic/template'

export default {
  data() {
    return {
      templateTypeList: [],
      visible: false,
      dataForm: {
        id: 0,
        templateName: '',
        templateNo: '',
        templateType: '',
        dataType: '',
        remark: ''
      },
      dataRule: {
        templateName: [
          { required: true, message: '模板名称不能为空', trigger: 'blur' }
        ],
        templateType: [
          { required: true, message: '模板类型不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        Promise.all([this.getDict(), this.getDataForm(this.dataForm.id)]).then(
          (res) => {}
        )
      })
    },
    getDataForm(id) {
      return new Promise((resolve, reject) => {
        if (id) {
          getObj(id)
            .then((response) => {
              if (response.data.code === 0) {
                this.dataForm = response.data.data
                resolve()
              } else {
                this.dataForm = {}
                reject()
              }
            })
            .catch((error) => {
              reject(error)
            })
        }
      })
    },
    getDict() {
      return new Promise((resolve, reject) => {
        getTemplateTypes()
          .then((response) => {
            if (response.data.code === 0) {
              this.templateTypeList = response.data.data
              resolve()
            } else {
              this.templateTypeList = []
              reject()
            }
          })
          .catch((error) => {
            reject(error)
          })
      })
    },
    templateTypeChange() {
      const currOperationTemplateType = this.dataForm.templateType
      const templateType = this.templateTypeList.find(
        (item) => item.templateTypeName === currOperationTemplateType
      )
      console.log(templateType)
      if (templateType != undefined) {
        this.dataForm.dataType = templateType.dataType
      } else {
        this.dataForm.dataType = ''
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
